/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

import org.objectweb.jorm.compiler.lib.JormCompiler;
import org.objectweb.jorm.lib.JormConfigurator;
import org.objectweb.jorm.compiler.lib.JormCompilerParameter;
import org.objectweb.jorm.api.PException;
import org.objectweb.util.monolog.api.LoggerFactory;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.Monolog;

import java.util.Collection;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class JormcRunner {

    static {
        if (!isAvaillable(JormConfigurator.DEFAULT_JORM_CONFIGURATION_FILE)) {
            System.out.println("File jormcOpts.properties is not availlable in the classpath");
            System.exit(-1);
        }
        if (!isAvaillable("jorm.properties")) {
            System.out.println("File jorm.properties is not availlable in the classpath");
            System.exit(-1);
        }
    }

    private static boolean isAvaillable(String fileName) {
        return OneOneBi.class.getClassLoader().getResourceAsStream(fileName)!=null;
    }

    public JormCompiler compiler = null;
    public static Logger logger = null;

    public JormcRunner(String projectName, String output) throws PException {
        compiler = new JormCompiler();
        JormCompilerParameter jcp = compiler.getCompilerParameter();
        JormConfigurator jcc = compiler.getCompilerConfigurator();
        jcc.configure();
        jcp.loadConfFile(jcc.getGlobalJormcOptsFile(), jcc.knownMappers());

        LoggerFactory loggerFactory = Monolog.init("jorm.properties");
        jcc.setLoggerFactory(loggerFactory);
        compiler.setupLogger();
        logger = compiler.getCompilerConfigurator().getLoggerFactory()
                .getLogger("orb.objectweb.jorm.examples.metainfo");
        compiler.setupMIManager();
        //compiler.setupVerifier(); currently the verifier is not availlable
        compiler.setupGenerator();
        compiler.getCompilerParameter().projectName = projectName;
        compiler.getCompilerParameter().output = output;
        Collection c = jcp.getSubMappers("rdb");
        logger.log(BasicLevel.DEBUG, "jormcOpts file:" + compiler.getCompilerConfigurator().getJormcOptsFile());
        logger.log(BasicLevel.DEBUG, "rdb sub mappers: " + c);
    }
    public Collection generate() throws PException {
        return compiler.generateFiles(compiler.getMIManager().getJormObjects());
    }

    public static Exception getInner(Exception e) {
        if (e instanceof PException
                && ((PException) e).getNestedException()!=null) {
            return getInner(((PException) e).getNestedException());
        }
        return e;
    }
}
