/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.metainfo.api.Class;
import org.objectweb.jorm.metainfo.api.PrimitiveElement;
import org.objectweb.jorm.metainfo.api.NameDef;
import org.objectweb.jorm.metainfo.api.GenClassRef;
import org.objectweb.jorm.metainfo.api.ScalarField;
import org.objectweb.jorm.metainfo.api.ClassRef;
import org.objectweb.jorm.metainfo.api.ClassProject;
import org.objectweb.jorm.metainfo.rdb.api.RdbMapping;
import org.objectweb.jorm.metainfo.rdb.api.RdbClassMapping;
import org.objectweb.jorm.metainfo.rdb.api.RdbTable;
import org.objectweb.jorm.metainfo.rdb.api.RdbGenClassMapping;
import org.objectweb.jorm.metainfo.rdb.api.RdbClassMultiMapping;
import org.objectweb.jorm.type.api.PTypeSpace;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class ManyManyBi extends JormcRunner {

    public final static String PROJECT_NAME = "jormExamples";
    public final static String A_CLASS_NAME = "org.objectweb.jorm.examples.mmb.A";
    public final static String B_CLASS_NAME = "org.objectweb.jorm.examples.mmb.B";


    public static void main(String[] args) {
        try {
            ManyManyBi mmb = new ManyManyBi(args.length == 0 ? "./" : args[0]);
            logger.log(BasicLevel.INFO, "Example ManyManyBi");
            mmb.createMIofA();
            mmb.createMIofB();
            mmb.generate();
        } catch (Exception e) {
            logger.log(BasicLevel.ERROR, "", getInner(e));
        }
    }
    public ManyManyBi(String output) throws PException {
        super(PROJECT_NAME, output);
    }

    public void createMIofA() throws PException {
        logger.log(BasicLevel.INFO, "Create the meta information of the A class");
        Class aclass = compiler.getMIManager().createClass(A_CLASS_NAME);

        PrimitiveElement ida =
                aclass.createPrimitiveElement("ida", PTypeSpace.LONG);
        PrimitiveElement f1 =
                        aclass.createPrimitiveElement("f1", PTypeSpace.STRING);

        // class identifier
        NameDef aNameDef = aclass.createNameDef();
        aNameDef.setFieldName(ida.getName());

        // mulitvalued reference to B
        GenClassRef bgcr = aclass.createGenClassRef("myB", "Set");
        //How the gen class is referenced
        NameDef myBNameDef = bgcr.createRefNameDef();
        myBNameDef.setFieldName(ida.getName());

        //how the gen clas is identified
        ScalarField fka = bgcr.createHiddenField("fka", PTypeSpace.LONG);
        NameDef  gcrIdNd = bgcr.createIdNameDef();
        gcrIdNd.setFieldName(fka.getName());

        //element of the gen class
        Class bclass = compiler.getMIManager().createClass(B_CLASS_NAME);
        ClassRef elemCr = bgcr.createClassRef(bclass);
        ScalarField fkb = bgcr.createHiddenField("fkb", PTypeSpace.LONG);
        NameDef gcrElemNd = elemCr.createRefNameDef();
        gcrElemNd.setFieldName(fkb.getName());


        // ----------------- Mapping for A -----------------
        ClassProject acp = aclass.createClassProject(PROJECT_NAME);
        RdbMapping am = (RdbMapping) acp.createMapping("rdb");

        RdbClassMapping acm = am.createClassMapping("to-table");
        RdbTable tableA = acm.createRdbTable("table_A");
        //Identifier of the A class
        acm.createIdentifierMapping(aNameDef);

        // Mapping rule of the reference myB
        acm.createReferenceMapping("embedded-target-reference", myBNameDef);

        // Mapping of the ida field over the pka_col
        tableA.createPrimitiveElementMapping(ida, "pka_col", null, true);
        // Mapping of the f1 field over the f1_col
        tableA.createPrimitiveElementMapping(f1, "f1_col", null, true);


        RdbGenClassMapping gccm =
                am.createGenClassMapping("embedded-target-references", bgcr);
        RdbTable tableGC = gccm.createRdbTable("table_JOIN");

        tableGC.createPrimitiveElementMapping(fka, "fka_col", null, true);
        tableGC.createPrimitiveElementMapping(fkb, "fkb_col", null, true);
        gccm.createIdentifierMapping(gcrIdNd);
        gccm.createReferenceMapping("embedded-target-reference", gcrElemNd);
    }

    public void createMIofB() throws PException {
        logger.log(BasicLevel.INFO, "Create the meta information of the B class");
        Class bclass = compiler.getMIManager().createClass(B_CLASS_NAME);
        PrimitiveElement idb =
                bclass.createPrimitiveElement("idb", PTypeSpace.LONG);
        PrimitiveElement f2 =
                bclass.createPrimitiveElement("f2", PTypeSpace.STRING);

        // pk simple
        NameDef bNameDef = bclass.createNameDef();
        bNameDef.setFieldName(idb.getName());

        // mulitvalued reference to A
        GenClassRef agcr = bclass.createGenClassRef("myA", "Set");
        //How the gen class is referenced
        NameDef myANameDef = agcr.createRefNameDef();
        myANameDef.setFieldName(idb.getName());

        //how the gen clas is identified
        ScalarField fkb = agcr.createHiddenField("fkb", PTypeSpace.LONG);
        NameDef  gcrIdNd = agcr.createIdNameDef();
        gcrIdNd.setFieldName(fkb.getName());

        //element of the gen class
        Class aclass = compiler.getMIManager().createClass(A_CLASS_NAME);
        ClassRef elemCr = agcr.createClassRef(aclass);
        ScalarField fka = agcr.createHiddenField("fka", PTypeSpace.LONG);
        NameDef gcrElemNd = elemCr.createRefNameDef();
        gcrElemNd.setFieldName("fka");

        // ----------------- Mapping for B -----------------

        ClassProject bcp = bclass.createClassProject(PROJECT_NAME);
        RdbMapping bm = (RdbMapping) bcp.createMapping("rdb");

        RdbClassMultiMapping bcm = bm.createClassMultiMapping("to-table");
        RdbTable tableB = bcm.createRdbTable("table_B");
        bcm.createIdentifierMapping(bNameDef);

        bcm.createReferenceMapping("embedded-target-reference", myANameDef);

        tableB.createPrimitiveElementMapping(idb, "pkb_col", null, true);
        tableB.createPrimitiveElementMapping(f2, "f2_col", null, true);

        RdbGenClassMapping gccm =
                bm.createGenClassMapping("embedded-target-references", agcr);
        RdbTable tableGC = gccm.createRdbTable("table_JOIN");

        tableGC.createPrimitiveElementMapping(fkb, "fkb_col", null, true);
        tableGC.createPrimitiveElementMapping(fka, "fka_col", null, true);
        gccm.createIdentifierMapping(gcrIdNd);
        gccm.createReferenceMapping("embedded-target-reference", gcrElemNd);
    }

}
