/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.api;

import org.objectweb.util.monolog.api.Logger;

import java.util.Collection;

/**
 * Defines the way to access the map clusters used to define and instanciate
 * the mapping structures.
 * @author	P. Dechamboux
 */
public interface PMappingStructuresManager {
	/**
	 * Asks for the map cluster associated with a JORM class.
	 * @param jcname The JORM class name.
	 * @return The relevant map cluster.
	 * @throws PException   This class has not been mapped.
	 */
	PMapCluster getPMapCluster(String jcname) throws PException;

	/**
	 * Asks for all the map clusters defined within this mapper.
	 * @return The Iterator over the collection of map clusters.
	 */
	Collection getPMapClusters();

	/**
	 * Adds a dependency between a defined class and another class.
	 * @param jcname1 is the class name of a defined class
	 * @param jcname2 is the name of the class which the first depends on it.
	 * @throws PException if the first jorm class name is not defined (no
	 * cluster found)
	 */
	void addDependency(String jcname1, String jcname2) throws PException;

	/**
	 * Indicates that a jorm class is defined.
	 * @param jcname which is defined.
	 */
	void classDefined(String jcname) throws PException;

	/**
	 * Assigns a mapper to this schema manager.
	 * @param pm	The concerned mapper.
	 */
	void setPMapper(PMapper pm);

	/**
	 * Assigns a logger to this schema manager.
	 * @param l		The concerned logger.
	 */
	void setLogger(Logger l);
}
