/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.facility.naming.polymorphid;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.naming.api.PNCStringCoder;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PNameGetter;
import org.objectweb.jorm.naming.api.PNamingContext;
import org.objectweb.jorm.naming.api.PExceptionNameCoding;
import org.objectweb.jorm.naming.api.PBinder;
import org.objectweb.jorm.naming.lib.BasicPNamingContext;
import org.objectweb.jorm.naming.lib.BasicStringCoder;
import org.objectweb.jorm.type.api.PType;

import java.util.HashMap;

/**
 * @author	P. Dechamboux
 */
public class PolymorphRefNC extends BasicPNamingContext
		implements PNamingContext {
	private HashMap validBinders = new HashMap(5);
	private PolymorphIdMgr mgr;
	PName nullPName = null;

	void init(PolymorphIdMgr mgr) {
		this.mgr = mgr;
		nullPName = new PolymorphIdRefN(this,
										(PolymorphIdPName) PolymorphIdPName.nullPName(this));

	}

	void addValidBinder(PolymorphIdBinderInfo b) {
		if (validBinders.get(b.classId) != null)
			return;
		validBinders.put(b.classId, b);
	}

	// IMPLEMENTATION OF METHODS FROM THE PNamingContext INTERFACE

	public boolean codingSupported(int codingtype) {
		switch (codingtype) {
		case PNamingContext.CTCOMPOSITE:
		case PNamingContext.CTSTRING:
			return true;
		}
		return false;
	}

	public PName decodeAbstract(Object en, Object context)
			throws PExceptionNaming, UnsupportedOperationException {
		long cid, oid;
		if (en instanceof PolymorphIdPNG) {
			// there is a specific PNamegetter
			try {
				oid = ((PolymorphIdPNG) en).pnGetObjectId(context);
				cid = ((PolymorphIdPNG) en).pnGetClassId(context);
			} catch (PException e) {
				throw new PExceptionNaming(e, "Wrong name structure!!");
			}
		} else if (en instanceof PNameGetter) {
			// we use the generic PNameGetter
			try {
				oid = ((PNameGetter) en).pngetLongField("objectId", context);
				cid = ((PNameGetter) en).pngetLongField("classId", context);
			} catch (PException e) {
				throw new PExceptionNaming(e, "Wrong name structure!!");
			}
		} else {
			throw new PExceptionNaming("A PNamegetter is required to decode this object :" + en);
		}
		if ((cid == PolymorphIdPName.NULLVALUE) &&
				(oid == PolymorphIdPName.NULLVALUE))
			return nullPName;
		PBinder b = (PBinder) validBinders.get(new Long(cid));
		if (b == null) {
			try {
				b = mgr.getPBinder(cid);
			} catch (PException e) {
				throw new PExceptionNaming(e, "Original binder (" + cid
											  + ") unavailable in the decoding PolymorphRefNC.");
			}
			validBinders.put(new Long(cid), b);
		}
		PolymorphIdRefN res = new PolymorphIdRefN(this);
		res.nameInBinder = new PolymorphIdPName(cid, oid, b);
		return res;
	}

	public PName decodeString(String en) throws PExceptionNaming {
		long cid, oid;
		try {
			PNCStringCoder cnsc = new BasicStringCoder(en);
			oid = cnsc.getLong();
			cid = cnsc.getLong();
		} catch (PException e) {
			throw new PExceptionNaming(e, "Wrong name structure!!");
		}
		if ((cid == PolymorphIdPName.NULLVALUE) &&
				(oid == PolymorphIdPName.NULLVALUE))
			return nullPName;
		PBinder b = (PBinder) validBinders.get(new Long(cid));
		if (b == null)
			throw new PExceptionNaming("Original binder unavailable in the decoding PolymorphRefNC.");
		PolymorphIdRefN res = new PolymorphIdRefN(this);
		res.nameInBinder = new PolymorphIdPName(cid, oid, b);
		return res;
	}

	public Object encodeAbstract(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		if (!(pn instanceof PolymorphIdRefN))
			throw new PExceptionNaming(
					"This PNamingContext encode only PolymorphIdRefN: " + pn);
		if (!((pn.getPNameManager()).equals(this)))
			throw new PExceptionNaming("This pname is not valid in this pnc");
		return ((PolymorphIdRefN) pn).nameInBinder;
	}

	public String encodeString(PName pn) throws PExceptionNaming {
		if (!(pn instanceof PolymorphIdRefN))
			throw new PExceptionNaming(
					"This PNamingContext encode only PolymorphIdRefN: " + pn);
		if (!((pn.getPNameManager()).equals(this)))
			throw new PExceptionNaming("This pname is not valid in this pnc");
		return ((PolymorphIdRefN) pn).nameInBinder.encodeString();
	}

	public PName export(Object conn, Object infoitem) throws PException {
		if (!(infoitem instanceof PolymorphIdPName))
			throw new PExceptionNaming("PolymorphIdRefNC export requires a " +
									   "PolymorphIdPName infoitem: " + infoitem);
		PolymorphIdRefN res = new PolymorphIdRefN(this);
		res.nameInBinder = (PolymorphIdPName) infoitem;
		return res;
	}

	public PName export(Object conn, Object infoitem, Object hints)
			throws PException {
		throw new PExceptionNaming("User-info not supported at export time.");
	}

	public PName getNull() {
		return nullPName;
	}

	public void setNullPName(Object o) throws PException {
		nullPName = (PName) o;
	}

	public void setPType(PType pt) {
		super.setPType(pt);
		mgr.ncTypeDef(this);
	}

	public PName resolve(Object conn, PName pn) throws PException {
		if (!(pn instanceof PolymorphIdRefN))
			throw new PExceptionNaming("Can only resolve PolymorphIdRefN names: " + pn);
		return ((PolymorphIdRefN) pn).nameInBinder;
	}

	public boolean supportDynamicComposite() {
		return true;
	}

	public boolean supportCompositeField(String fn, PType ft) {
		return true;
	}

	public boolean supportStaticComposite() {
		return true;
	}

	public void unexport(Object conn, PName pn) throws PException {
	}

	public void unexport(Object conn, PName pn, Object hints) throws PException {
	}
}
