/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.facility.naming.rdbsequence;

import org.objectweb.jorm.naming.lib.BasicPName;
import org.objectweb.jorm.naming.api.PNameManager;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.naming.api.PNameGetter;
import org.objectweb.jorm.api.PException;

import java.util.Date;
import java.math.BigDecimal;
import java.math.BigInteger;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class RdbSequencePName extends BasicPName implements PNameGetter {
	public final static long NULL_VALUE = 0;
	long value = NULL_VALUE;

	public RdbSequencePName(PNameManager pnm, long value) {
		this.pnc = pnm;
		this.value = value;
	}

	public RdbSequencePName(PNameManager pnm, Object hints) throws PExceptionNaming {
		this.pnc = pnm;
		if (!(hints instanceof RdbSequencePName)) {
			throw new PExceptionNaming("Unsupported operation: bad pname type,"
									   + " expected RdbSequencePName: " + hints);
		}
		value = ((RdbSequencePName) hints).value;
	}

	public String toString() {
		return super.toString() + " / pncRef:" + pnc + " / value:" + value;
	}

	public boolean equals(Object obj) {
		return (obj instanceof RdbSequencePName)
				&& ((RdbSequencePName) obj).value == value
				&& pnc == ((RdbSequencePName) obj).pnc;
	}

	public int hashCode() {
		return (int) value;
	}

	public boolean isNull() {
		return value == NULL_VALUE;
	}

	public byte pngetByteField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public Byte pngetObyteField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public char pngetCharField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public Character pngetOcharField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public short pngetShortField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public Short pngetOshortField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public int pngetIntField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public Integer pngetOintField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public long pngetLongField(String fn, Object ctxt) throws PException {
		return value;
	}

	public Long pngetOlongField(String fn, Object ctxt) throws PException {
		return new Long(value);
	}

	public String pngetStringField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public byte[] pngetByteArrayField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public char[] pngetCharArrayField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public Date pngetDateField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public BigDecimal pngetBigDecimalField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}

	public BigInteger pngetBigIntegerField(String fn, Object ctxt) throws PException {
		throw new PExceptionNaming("Bad type: expected long");
	}
}
