/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.fos.metainfo;

import org.objectweb.jorm.util.api.Loggable;
import org.objectweb.jorm.metainfo.api.MappingFactory;
import org.objectweb.jorm.metainfo.api.Mapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.MappingPrinter;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.LoggerFactory;

import java.io.Serializable;

/**
 * @author	P. Dechamboux
 */
public class FosMappingFactory
	implements MappingFactory, Loggable, Serializable {
	transient protected Logger logger = null;
	transient protected LoggerFactory loggerFactory = null;

	// IMPLEMENTATION OF METHDOS FROM THE MappingFactory INTERFACE

    /**
     * Creates a new BasicFosMapping object.
     * @param mapperName	the name of the mapper,
     *        parent     the parent object.
     * @return a new RdbMapping object.
     */
     public Mapping createMapping(String mapperName, MetaObject parent) {
         FosMapping mapping = new FosMapping(mapperName, parent);
         return mapping;
     }

     public MappingPrinter createMappingPrinter() {
         return new FosMappingPrinter();
     }

	// IMPLEMENTATION OF METHDOS FROM THE Loggable INTERFACE

	public Logger getLogger() {
		return logger;
	}

	public LoggerFactory getLoggerFactory() {
		return loggerFactory;
	}

	public void setLogger(Logger l) {
		logger = l;
	}

	public void setLoggerFactory(LoggerFactory lf) {
		loggerFactory = lf;
		if (loggerFactory!=null && logger==null)
			loggerFactory.getLogger(getClass().getName());
	}
}
