/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.adapter;

import java.util.List;
import java.util.ArrayList;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class JoinedTable {
	public class Join {

		public List colT1;
		public List colT2;

		public Join() {
			colT1 = new ArrayList();
			colT2 = new ArrayList();
		}

		public void addJoinColumn(String col1, String col2) {
			colT1.add(col1);
			colT2.add(col2);
		}
	}

	public List joins;
	public List joinedTables;
	public String tableName;
	public String alias;


	public JoinedTable(String tablename) {
		this(tablename, null);
	}

	public Join createChildren(String tablename) {
		return createChildren(tablename, null);
	}

	public Join createChildren(String tablename, String alias) {
		joinedTables.add(new JoinedTable(tablename, alias));
		Join j = new Join();
		joins.add(j);
		return j;
	}

	public Join createChildren(JoinedTable jt) {
		joinedTables.add(jt);
		Join j = new Join();
		joins.add(j);
		return j;
	}

	public JoinedTable(String tablename, String alias) {
		tableName = tablename;
		this.alias = alias;
		joins = new ArrayList();
		joinedTables = new ArrayList();
	}

	public boolean contains(JoinedTable jt) {
		if (joinedTables.indexOf(jt) != -1) {
			return true;
		}
		for (int i = 0; i < jt.joinedTables.size(); i++) {
			if (((JoinedTable) jt.joinedTables.get(i)).contains(jt)) {
				return true;
			}
		}
		return false;
	}
}
