/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.adapter;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.api.PExceptionProtocol;

/**
 * This class is a sql adapter for the SQL Server relational database.
 *
 * @author P. Dechamboux
 */
public class SqlserverAdapter extends BasicRdbAdapter {

	public SqlserverAdapter() {
		super();
	}

	public String getSqlType(PType pt, boolean usedInPK, int size) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql Type name associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
			return "SMALLINT";
		case PType.TYPECODE_BYTEARRAY:
			if ((size != PType.NOSIZE) && (size <= 8000)) {
				return "VARBINARY(" + size + ")";
			}
			return "IMAGE";
		case PType.TYPECODE_CHARARRAY:
			if ((size != PType.NOSIZE) && (size <= 8000)) {
				return "VARCHAR(" + size + ")";
			}
			return "TEXT";
		case PType.TYPECODE_FLOAT:
		case PType.TYPECODE_OBJFLOAT:
			return "FLOAT(24)";
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
			return "FLOAT(53)";
		case PType.TYPECODE_DATE:
			return "DATETIME";
		case PType.TYPECODE_BIGINTEGER:
		case PType.TYPECODE_BIGDECIMAL:
			return "MONEY";
		default:
			return super.getSqlType(pt, usedInPK, size);
		}
	}

	public String getSqlGetterName(PType pt, String resultSet, int idx,
								   String sqlColumnType) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql getter associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_CHARARRAY:
			return resultSet + ".getString(" + idx + ")";
		default:
			return super.getSqlGetterName(pt, resultSet, idx, sqlColumnType);
		}
	}

	public String getSqlSetterName(PType pt, String value, int idx,
								   String sqlColumnType) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql setter associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_OBJBYTE:
			return "setObject(" + idx + ", " + value + ", Types.SMALLINT)";
		case PType.TYPECODE_OBJCHAR:
			return "setString(" + idx + ", " + value + ".toString())";
		case PType.TYPECODE_CHARARRAY:
			return "setString(" + idx + ", new String(" + value + "))";
		default:
			return super.getSqlSetterName(pt, value, idx, sqlColumnType);
		}
	}
}
