/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.metainfo;

import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.lib.BasicClassMapping;

/**
 * Description
 */
public class RdbClassMapping extends BasicClassMapping {
	RdbTable table = null;

    RdbFilter filter = null;

	/**
	 * Builds a new BasicRdbClassMapping object.
	 *
	 * This object contains the mapping structure of the class it refers to.
	 * The parent object is a Mapping object that contains the mapper name.
	 *
	 * @param ruleName  the name of the rule used to map the class,
	 *        linkedMo	the Class object referenced by the current object,
	 *        parent	the parent of the current object.
	 */
	public RdbClassMapping(String ruleName, MetaObject linkedMO,
								MetaObject parent) {
		super(ruleName, linkedMO, parent);
	}

	///////////////////////////////////////////////////////////////////
	//                      from RdbClassMapping interface
	///////////////////////////////////////////////////////////////////

	public RdbTable createRdbTable(String tableName) {
		if (table == null) {
			table = new RdbTable(this, getLinkedMO(), tableName);
			table.setLogger(getLogger());
			table.setLoggerFactory(getLoggerFactory());
		} else {
			table.setName(tableName);
		}
		return table;
	}

	public RdbTable getRdbTable() {
		return table;
	}

    public RdbFilter createRdbFilter() {
       filter = new RdbFilter(this);
       return filter;
    }

	public RdbFilter getRdbFilter() {
		return filter;
	}
}
