/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.metainfo;

import org.objectweb.jorm.metainfo.lib.BasicMetaObject;
import org.objectweb.jorm.metainfo.lib.Predicate;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.api.PException;

import java.util.ArrayList;
import java.util.List;
import java.util.HashMap;
import java.util.Set;

public class RdbFilter extends BasicMetaObject {

    /**
     * This map associates a list of Predicate objects to a filter column.
	 * key: the name of the filter column
	 * value: a list of Predicate objects
     */
    HashMap filtercol2predicates = null;

	/**
	 * Builds a new RdbFilter object.
	 *
	 * This object encapsulates information about filter columns.
	 * The parent object is a RdbClassMapping object.
	 *
	 * @param parent	the parent of the current object.
	 */
	public RdbFilter(MetaObject parent) {
		super(parent);
        filtercol2predicates = new HashMap();
	}

    public void addFilterColumn(String columnName) throws PException {
        if (filtercol2predicates.containsKey( columnName)) {
			throw new PException("Column " + columnName
								 + " already defined as filter column!!");
		}
        filtercol2predicates.put(columnName, new ArrayList());
    }

    public void addPredicate(String columnName, Predicate predicate) throws PException {
        if (! filtercol2predicates.containsKey( columnName)) {
			throw new PException("you are trying to associate a predicate with a column " +
                                 columnName + " that does not exist!!");
		}
        ((ArrayList) filtercol2predicates.get(columnName)).add(predicate);
    }

 	/**
	 * Returns a collection of filter column names.
	 * @return a collection of filter column names.
	 */
    public Set getFilterColumnNames() {
        return filtercol2predicates.keySet();
    }

	/**
	 * Returns a collection of Predicate objects.
     *
     * @param filterColumnName   a filter column name.
	 * @return a collection of Predicate objects.
	 */
    public List getPredicates(String filterColumnName) {
        return (List) filtercol2predicates.get(filterColumnName);
    }
}
