/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.metainfo;

import org.objectweb.jorm.metainfo.lib.BasicMetaObject;
import org.objectweb.jorm.metainfo.api.MetaObject;

import java.util.ArrayList;
import java.util.List;

/**
 * Implementation of the RdbJoin interface. The join relationship requires two
 * columns represented by primaryTableColumnName and externalTableColumnName.
 *
 * @see	    RdbClassMultiMapping
 */
public class RdbJoin extends BasicMetaObject implements Comparable {
    /**
     * Column names of the primary table involved in the join.
     */
    private ArrayList ptJoinColumnNames;

    /**
     * Column names of the external table involved in the join.
     */
    private ArrayList etJoinColumnNames;

    private String name;
    /**
     * Builds a new BasicRdbJoin object.
     *
     * The parent object is a RdbClassMultiMapping object. The name of the two
     * tables involved in the join relationship is accessible from the parent
     * object.
     *
     * @param parent   the parent of the current object.
     */
    public RdbJoin(MetaObject parent, String name) {
        super(parent);
        this.name = name;
        this.ptJoinColumnNames = new ArrayList();
        this.etJoinColumnNames = new ArrayList();
    }

    public int compareTo(Object o) {
        return name.compareTo(((RdbJoin) o).getName());
    }

    ///////////////////////////////////////////////////////////////////
    //                      from RdbJoin interface
    ///////////////////////////////////////////////////////////////////

	/**
	 * Returns a collection of column names involved in the join.
	 * @return a collection of column names involved in the join.
	 */
    public List getPTJoinColumnNames() {
        return ptJoinColumnNames;
    }

	/**
	 * Returns a collection of column names involved in the join.
	 * @return a collection of column names involved in the join.
	 */
    public List getETJoinColumnNames() {
        return etJoinColumnNames;
    }

	/**
	 * Adds two join column names.
	 */
    public void addJoinColumnNames(String ptJoinColumnName,
                                   String etJoinColumnName) {
        if (! ptJoinColumnNames.contains( ptJoinColumnName)) {
            if (! etJoinColumnNames.contains( etJoinColumnName)) {
                ptJoinColumnNames.add(ptJoinColumnName);
                etJoinColumnNames.add(etJoinColumnName);
            }
        }
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}
