/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.api;

import java.util.Iterator;
import java.util.Collection;

/**
 * todo: Description
 */
public interface HelperClassMapping extends MappingStructure {

	/**
	 * Returns the  name of the rule used to map the class.
	 * @return	 the name of the rule.
	 */
	String getRuleName();

	/**
	 * Sets the name of the rule used to map the class.
	 * @param rulename the name of the rule.
	 */
	void setRuleName(String rulename);

	/**
	 * Returns the IdentifierMapping object.
	 * @return	an IdentifierMapping object.
	 */
	IdentifierMapping getIdentifierMapping();

	/**
	 * Sets the IdentifierMapping object.
	 * @param idmapping the IdentifierMapping object.
	 */
	void setIdentifierMapping(IdentifierMapping idmapping);

	/**
	 * Returns a collection of PrimitiveElementMapping objects.
	 * @return  a collection.
	 */
	Collection getPrimitiveElementMappings();

	/**
	 * Returns the PrimitiveElementMapping objects matching to the fieldName
	 * specified.
	 * @param fieldName is a name of a primitivite field (hidden or not) of
	 * the class
	 * @return  a collection.
	 */
	PrimitiveElementMapping getPrimitiveElementMapping(String fieldName);

	/**
	 * Adds a PrimitiveElementMapping object.
	 * @param  pemapping  the PrimitiveElementMapping object to add to the list.
	 */
	void addPrimitiveElementMapping(PrimitiveElementMapping pemapping);

	/**
	 * Adds a PrimitiveElementMapping object.
	 * @param  pemapping  the PrimitiveElementMapping object to add to the list.
	 */
	void addPrimitiveElementMapping(String fieldName, PrimitiveElementMapping pemapping);

	/**
	 * Returns an Iterator over PrimitiveElementMapping objects.
	 * @return  an Iterator.
	 */
	Iterator iteratePrimitiveElementMappings();

	/**
	 * Creates a new IdentifierMapping object.
	 * @param   nd	the NameDef object that defines an object identifier.
	 * @return	an IdentifierMapping object.
	 */
	IdentifierMapping createIdentifierMapping(NameDef nd);

	/**
	 * Creates a new ReferenceMapping object.
	 * @param ruleName  the name of the rule used to map the reference,
	 *        nd	    the NameDef object that defines an object reference.
	 * @return	a ReferenceMapping object.
	 */
	ReferenceMapping createReferenceMapping(String ruleName, NameDef nd);

	void addDependency(String jormClassName);

	void removeDependency(String jormClassName);

	Collection getDependencies();
}
