/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.api;

import java.util.Iterator;

/**
 * A PrimitiveElement is a field with a primitive type. Type can be
 * boolean | byte | char | short | int | long | float | double |
 * string | serialized| date | time | timestamp
 * A primitive type can not be extended.
 * @author	X. Spengler
 */
public interface PrimitiveElement extends TypedElement {
	/**
	 * Allows to know if the current Field is a scalar field or not.
	 *
	 * @return	true, if the Field is scalar, else false, if the Field is not
	 *          scalar
	 */
	boolean isScalar();

	/**
	 * Returns the size of the field in case of string, serialized, arrays, etc
	 * @return the size for this type
	 */
	int getSize();
}
