/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.lib;

import org.objectweb.jorm.metainfo.api.Class;
import org.objectweb.jorm.metainfo.api.ClassMapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.ReferenceMapping;
import org.objectweb.jorm.metainfo.api.NameDef;
import org.objectweb.jorm.metainfo.api.Reference;
import org.objectweb.jorm.metainfo.api.ClassRef;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;

/**
 * BasicClassMapping is THE basic implementation of the ClassMapping interface. * Its defines basic methods, and must be extended to different mappers.
 * @author	X. Spengler
 */
public class BasicClassMapping extends BasicHelperClassMapping
		implements ClassMapping {
	/**
	 * A vector of ReferenceMapping objects.
	 *
	 * Each element of the vector encapsulates a NameDef object that defines a
	 * reference to a class instance or a generic class instance.
	 */
	private List fieldNames;
	private List referenceMappings;

	/**
	 * Builds a new BasicClassMapping.
	 * @param ruleName  the name of the rule used to map the class,
	 *        linkedMO	the object referenced by the current object,
	 *        parent	the parent of the current object.
	 */
	public BasicClassMapping(String ruleName, MetaObject linkedMO,
							 MetaObject parent) {
		super(ruleName, linkedMO, parent);
		referenceMappings = new ArrayList();
		fieldNames = new ArrayList();
	}

	///////////////////////////////////////////////////////////////////
	//                      from ClassMapping interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Adds a ReferenceMapping object.
	 *
	 * @param  refMapping  the ReferenceMapping object to add to the list.
	 */
	public void addReferenceMapping(ReferenceMapping refMapping) {
		Reference r = (Reference) refMapping.getLinkedMO().getParent();
		referenceMappings.add(refMapping);
		fieldNames.add(r.getName());
		// TODO : optimize the generation of dependencies using the rule name
		/*
		if (r instanceof ClassRef) {
			this.addDependency(((ClassRef) r).getMOClass().getFQName());
		}
		*/

	}

	public ReferenceMapping createReferenceMapping(String ruleName, NameDef nd) {
		ReferenceMapping res = super.createReferenceMapping(ruleName, nd);
		addReferenceMapping(res);
		return res;
	}

	public ReferenceMapping getReferenceMapping(String referenceName) {
		int idx = fieldNames.indexOf(referenceName);
		return (idx == -1
				? null
				: (ReferenceMapping) referenceMappings.get(idx));
	}

	/**
	 * Returns an Iterator over ReferenceMapping objects.
	 *
	 * @return  an Iterator.
	 */
	public Iterator iterateReferenceMappings() {
		return referenceMappings.iterator();
	}

	/**
	 * Returns a collection of ReferenceMapping objects.
	 *
	 * @return  a collection.
	 */
	public Collection getReferenceMappings() {
		return referenceMappings;
	}
}
