/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.metainfo.lib;

import org.objectweb.jorm.metainfo.api.GenClassMapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.ReferenceMapping;
import org.objectweb.jorm.metainfo.api.NameDef;
import org.objectweb.jorm.util.api.Loggable;

/**
 * Description
 */
public class BasicGenClassMapping extends BasicHelperClassMapping
		implements GenClassMapping, Loggable {
	/**
	 * A ReferenceMapping object.
	 * A ReferenceMapping object encapsulates a NameDef object that defines a
	 * reference to a class instance or a generic class instance.
	 */
	private ReferenceMapping referenceMapping;

	/**
	 * Builds a new BasicGenClassMapping.
	 * @param ruleName  the name of the rule used to map the class,
	 *        linkedMO	the object referenced by the current object,
	 *        parent	the parent of the current object.
	 */
	public BasicGenClassMapping(String ruleName, MetaObject linkedMO,
								MetaObject parent) {
		super(ruleName, linkedMO, parent);
		this.referenceMapping = null;
	}

	///////////////////////////////////////////////////////////////////
	//                      from GenClassMapping interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Sets a ReferenceMapping object.
	 * @param  refMapping  the ReferenceMapping object.
	 */
	public void setReferenceMapping(ReferenceMapping refMapping) {
		this.referenceMapping = refMapping;
	}

	/**
	 * Returns a ReferenceMapping object.
	 * @return  a ReferenceMapping object.
	 */
	public ReferenceMapping getReferenceMapping() {
		return referenceMapping;
	}

	public ReferenceMapping createReferenceMapping(String ruleName, NameDef nd) {
		ReferenceMapping res = super.createReferenceMapping(ruleName, nd);
		setReferenceMapping(res);
		return res;
	}
}
