/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.lib;

import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.Manager;

import java.util.Iterator;

/**
 * Description
 */
public class BasicMetaObject implements MetaObject {

	/**
	 * The parent of the current object.
	 */
	private MetaObject parent;

	/**
	 * Builds a new BasicMetaObject object.
	 *
	 * @param parent    the parent of the current object
	 */
	public BasicMetaObject(MetaObject parent) {
        this.parent = parent;
    }

	///////////////////////////////////////////////////////////////////
	//                      from MetaObject interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Returns the parent MetaObject of the current MetaObject.
	 *
	 * @return	the MetaObject corresponding to the parent of the
	 *  		current object. If there is no parent, null is returned.
	 */
	public MetaObject getParent() {
		return parent;
	}

	/**
	 * Sets the parent of the current meta object if it is not yet done
	 * by the constructor of the meta object
	 * @param parent	the parent MetaObject of the current object
	 */
	public void setParent(MetaObject parent) {
        this.parent = parent;
	}

	/**
	 * Returns the Manager object.
	 * @return the Manager object.
	 */
    public Manager getManager() {
		MetaObject tmp = parent;
		MetaObject manager = null;
		while (tmp != null) {
			manager = tmp;
			tmp = tmp.getParent();
		}
        return (Manager) manager;
    }
}