/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mi2xml.api;

import org.objectweb.jorm.lib.JormConfigurator;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.util.io.api.TargetHolder;

/**
 * Writer generates Jorm specification files (.pd files) from a Class or a CompositeName object.
 */
public interface Writer {
	/**
	 * Initializes a BasicDomWriter object.
	 * @param compilerConfigurator  a JormConfigurator object.
	 */
	void init(JormConfigurator compilerConfigurator) throws PException;

	/**
	 * This method first builds the DOMTree of a Class or a CompositeName object and
	 * then generates the .pd file by delegation to the XMLSerializer.
	 * @param mo		a Class or a CompositeName object.
	 * @param holder	The target holder which allows to create files.
	 * @exception PException if an error occurs during the generation.
	 */
	void write(MetaObject mo, TargetHolder holder)
			throws PException;
}
