/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.naming.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.naming.api.PNameCoder;

/**
 * This class is a helper which permits to convert PType code to a pname coding
 * type.
 *
 * @author S.Chassande-Barrioz
 */
public class CTHelper {

	/**
	 * It convertes a Coding type to a PType code
	 */
	public static int ct2ptc(short ct) {
		switch (ct) {
		case PNameCoder.CTCHAR:
			return PType.TYPECODE_CHAR;
		case PNameCoder.CTOCHAR:
			return PType.TYPECODE_OBJCHAR;

		case PNameCoder.CTBYTE:
			return PType.TYPECODE_BYTE;
		case PNameCoder.CTOBYTE:
			return PType.TYPECODE_OBJBYTE;

		case PNameCoder.CTSHORT:
			return PType.TYPECODE_SHORT;
		case PNameCoder.CTOSHORT:
			return PType.TYPECODE_OBJSHORT;

		case PNameCoder.CTINT:
			return PType.TYPECODE_INT;
		case PNameCoder.CTOINT:
			return PType.TYPECODE_OBJINT;

		case PNameCoder.CTLONG:
			return PType.TYPECODE_LONG;
		case PNameCoder.CTOLONG:
			return PType.TYPECODE_OBJLONG;

		case PNameCoder.CTSTRING:
			return PType.TYPECODE_STRING;

		case PNameCoder.CTBYTEARRAY:
			return PType.TYPECODE_BYTEARRAY;
		case PNameCoder.CTCHARARRAY:
			return PType.TYPECODE_CHARARRAY;
		case PNameCoder.CTDATE:
			return PType.TYPECODE_DATE;
		default:
			return -1;
		}
	}

	/**
	 * It convertes a PType code to a Coding type.
	 */
	public static short ptc2ct(int tpc) {
		switch (tpc) {
		case PType.TYPECODE_CHAR:
			return PNameCoder.CTCHAR;
		case PType.TYPECODE_OBJCHAR:
			return PNameCoder.CTOCHAR;

		case PType.TYPECODE_BYTE:
			return PNameCoder.CTBYTE;
		case PType.TYPECODE_OBJBYTE:
			return PNameCoder.CTOBYTE;

		case PType.TYPECODE_SHORT:
			return PNameCoder.CTSHORT;
		case PType.TYPECODE_OBJSHORT:
			return PNameCoder.CTOSHORT;

		case PType.TYPECODE_INT:
			return PNameCoder.CTINT;
		case PType.TYPECODE_OBJINT:
			return PNameCoder.CTOINT;

		case PType.TYPECODE_LONG:
			return PNameCoder.CTLONG;
		case PType.TYPECODE_OBJLONG:
			return PNameCoder.CTOLONG;

		case PType.TYPECODE_STRING:
			return PNameCoder.CTSTRING;

		case PType.TYPECODE_BYTEARRAY:
			return PNameCoder.CTBYTEARRAY;
		case PType.TYPECODE_CHARARRAY:
			return PNameCoder.CTCHARARRAY;
		case PType.TYPECODE_DATE:
			return PNameCoder.CTDATE;
		default:
			return -1;
		}
	}
}
