/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.verifier.api;

import org.objectweb.jorm.metainfo.api.Manager;

import java.util.Collection;

/**
 * It provides the functions used to verify the semantical correctness of
 * meta-information.
 * @author	P. Dechamboux
 */
public interface Verifier {
	/**
	 * Assigns the meta information manager to this Verifier.
	 * @param mim   the meta information manager to use.
	 */
	void setMetaInfoManager(Manager mim);

	/**
	 * Assigns a project name to this verifier.
	 * @param name	The associated name.
	 */
	void setProjectName(String name);

	/**
	 * Adds a mapping verifier which verifies a specific mapping part of the
	 * meta information.
	 * @param mappername		The name of the mapper.
	 * @param mappingVerifier   The Mapping Verifier object.
	 */
	void addMappingVerifier(String mappername, MappingVerifier mappingVerifier);

	/**
	 * Verifies the meta information.
	 */
	void verify(Collection mos);
}
